import sys
import salome

salome.salome_init()
theStudy = salome.myStudy

import salome_notebook
notebook = salome_notebook.NoteBook(theStudy)

#WORKING DIRECTORY
working_dir = r'/home/jobin/Documents/code-aster/01-exp_muff_python_all/'
sys.path.insert(0, working_dir)

#===================================================================================================#
#											SIMULATION INFO											#
#===================================================================================================#
import numpy
T = 25 + 273.15
freq_normalized_max = 4.0
L2 = 0.5

c = 20.05*numpy.sqrt(T)
f_max = freq_normalized_max*c/2.0/L2

mesh_size_max = float(c/f_max/10.0)
print 'Mesh Max Size: ' + str(mesh_size_max) + ' m'

#===================================================================================================#
#											GEOMETRY (GEOM)											#
#===================================================================================================#

import GEOM
from salome.geom import geomBuilder
import math
import SALOMEDS

geompy = geomBuilder.New(theStudy)

#Base Geometry Setup
O = geompy.MakeVertex(0, 0, 0)
OX = geompy.MakeVectorDXDYDZ(1, 0, 0)
OY = geompy.MakeVectorDXDYDZ(0, 1, 0)
OZ = geompy.MakeVectorDXDYDZ(0, 0, 1)
OZneg = geompy.MakeVectorDXDYDZ(0, 0, -1)

#External Geometry
def in_to_m(a):
	return a*0.0254

L1 = 0.1
#L2 = 0.5
L3 = L1
Lt = L1+L2+L3
D1 = 0.05
D2 = 0.20

La = 0.112 #L2/4.0 w/ end correction
Lb = 0.237 #L2/2.0 w/ end correction

inlet_tube_start_pt 	= geompy.MakeVertex(0, 0, 0)
exp_tube_start_pt 		= geompy.MakeVertex(0, 0, L1)
outlet_tube_start_pt 	= geompy.MakeVertex(0, 0, L1+L2)

inlet_tube = geompy.MakeCylinder(inlet_tube_start_pt, OZ, D1/2.0, L1)
exp_tube = geompy.MakeCylinder(exp_tube_start_pt, OZ, D2/2.0, L2)
outlet_tube = geompy.MakeCylinder(outlet_tube_start_pt, OZ, D1/2.0, L3)

inlet_tube_inlet_face = geompy.ExtractShapes(inlet_tube, geompy.ShapeType["FACE"], True)[0]

inlet_tube_end_face = geompy.ExtractShapes(inlet_tube, geompy.ShapeType["FACE"], True)[2]
exp_tube_end_face = geompy.ExtractShapes(exp_tube, geompy.ShapeType["FACE"], True)[2]


#Adding elements to study
geompy.addToStudy(O, 'O')
geompy.addToStudy(OX, 'OX')
geompy.addToStudy(OY, 'OY')
geompy.addToStudy(OZ, 'OZ')
geompy.addToStudy(exp_tube, 'exp_tube')
geompy.addToStudy(inlet_tube, 'inlet_tube')
geompy.addToStudy(inlet_tube_end_face, 'inlet_tube_end_face')
geompy.addToStudy(exp_tube_end_face, 'exp_tube_end_face')

#===================================================================================================#
#											MESHING (SMESH)											#
#===================================================================================================#
import  SMESH, SALOMEDS
from salome.smesh import smeshBuilder

smesh = smeshBuilder.New(theStudy)
Mesh_1 = smesh.Mesh(exp_tube)

# Define 1D algorithm and hypothesis
algo1d = Mesh_1.Segment() 
algo1d.MaxSize(mesh_size_max)

# Define 2D algorithm and hypothesis
algo2d = Mesh_1.Triangle(algo=smeshBuilder.MEFISTO)

# Define 3D algorithm and hypothesis
algo3d = Mesh_1.Tetrahedron()

# Compute the mesh
Mesh_1.Compute() 


Mesh_2 = smesh.Mesh(inlet_tube)

# Define 1D algorithm and hypothesis
algo1d = Mesh_2.Segment() 
algo1d.MaxSize(mesh_size_max)

# Define 2D algorithm and hypothesis
algo2d = Mesh_2.Triangle(algo=smeshBuilder.MEFISTO)

# Define 3D algorithm and hypothesis
algo3d = Mesh_2.Tetrahedron()

# Compute the mesh
Mesh_2.Compute() 

def Group_BelongToGeom(Mesh, geometry, selection_name, selection_type):
	
	if selection_type == 'node':
		selection_obj = SMESH.NODE
		
	elif selection_type == 'face':
		selection_obj = SMESH.FACE
		
	else:
		print 'ERROR: Incorrect selection_type!'
		return	
		
	aFilter = smesh.GetFilter(selection_obj, SMESH.FT_BelongToGeom, geometry)
	anIds = Mesh.GetIdsFromFilter(aFilter)
	aGroup = Mesh.CreateEmptyGroup(selection_obj, selection_name)
	aGroup.Add(anIds)
	
Group_BelongToGeom(Mesh_1, inlet_tube_end_face, 'exp_tube_connection', 'face')
Group_BelongToGeom(Mesh_1, exp_tube_end_face, 'outlet', 'face')
Group_BelongToGeom(Mesh_2, inlet_tube_inlet_face, 'inlet', 'face')
Group_BelongToGeom(Mesh_2, inlet_tube_end_face, 'inlet_tube_connection', 'face')




# --- update the study object browser
if salome.sg.hasDesktop():
	salome.sg.updateObjBrowser()
