subroutine fgdomg(method, nommat, nomnap, nomfon, valmin,&
                  valmax, ncyc, dommag)
!       ================================================================
    implicit none
!
#include "asterf_types.h"
#include "jeveux.h"
#include "asterfort/fgcorr.h"
#include "asterfort/fgdoba.h"
#include "asterfort/fgdohs.h"
#include "asterfort/fgdoma.h"
#include "asterfort/fgdowh.h"
#include "asterfort/fgtaep.h"
#include "asterfort/fgtaes.h"
#include "asterfort/getvtx.h"
#include "asterfort/jedetr.h"
#include "asterfort/jemarq.h"
#include "asterfort/jedema.h"
#include "asterfort/rcpare.h"
#include "asterfort/rcvale.h"
#include "asterfort/utmess.h"
#include "asterfort/wkvect.h"
#include "asterfort/as_deallocate.h"
#include "asterfort/as_allocate.h"
    character(len=*) :: method
    character(len=8) :: nommat, nomnap, nomfon
    real(kind=8) :: valmin(*), valmax(*), dommag
    integer :: ncyc
!
! ======================================================================
! COPYRIGHT (C) 1991 - 2016  EDF R&D                  WWW.CODE-ASTER.ORG
! THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
! IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
! THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
! (AT YOUR OPTION) ANY LATER VERSION.
!
! THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
! WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
! MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
! GENERAL PUBLIC LICENSE FOR MORE DETAILS.
!
! YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
! ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
!    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
! ======================================================================
!       ----------------------------------------------------------------
!       CALCUL DU DOMMAGE PAR DIFFERENTES METHODES
!       ----------------------------------------------------------------
!       IN  METHOD  METHODE DE CALCUL  DE DOMMAGE EMPLOYEE
!                       /WOHLER
!                       /MANSON_COFFIN
!                       /TAHERI_MANSON
!                       /TAHERI_MIXTE
!           NOMMAT  NOM DU CHAM_MATER
!           NOMNAP  NOM DE LA NAPPE POUR LOI DE TAHERI
!           NOMFON  NOM DE LA FONCTION POUR LOI DE TAHERI
!           CYCLE   TABLE DES CYCLES DETECTES (INDICES DEB ET FIN)
!           NCYC    NOMBRE  DE  CYCLE
!       OUT DOMMAG  VALEUR DU DOMMAGE
!       ----------------------------------------------------------------
    integer :: icodwo, icodba, icodhs
    character(len=32) :: pheno
    character(len=16) :: cara,k16b
    aster_logical :: lke, lhaigh
!
!-----------------------------------------------------------------------
    integer :: i, ivcorr, ivke
    real(kind=8), pointer :: vdommag(:) => null()
!-----------------------------------------------------------------------
    integer :: n1, nbpar
    integer :: icodre(3)
    real(kind=8) :: r8b, val(3)
    character(len=8) :: kcorre, nompar
    character(len=16) :: nomres(3)
!
    r8b = 0.d0
    dommag = 0.d0
    pheno = 'FATIGUE'
    AS_ALLOCATE(vr=vdommag, size=ncyc)
    lke = .false.
    lhaigh = .false.
    ivke = 0
    ivcorr = 0
!
    call jemarq()
!
    if (method .eq. 'WOHLER') then
!----------------------------------------------------------------    
        kcorre = ' '
        call getvtx(' ', 'CORR_SIGM_MOYE', scal=kcorre, nbret=n1)
        if (kcorre .ne. ' ') then
            nomres(1) = 'SU'
            nbpar = 0
            nompar = ' '
            call rcvale(nommat, 'RCCM', nbpar, nompar, [r8b],&
                        1, nomres, val, icodre, 2)
            call wkvect('&&FGDOMG.HAIGC', 'V V R', ncyc, ivcorr) 
            lhaigh = .true.
            call fgcorr(ncyc, valmin, valmax, kcorre, val(1),&
                        zr(ivcorr))
        endif
        cara = 'WOHLER'
        call rcpare(nommat, pheno, cara, icodwo)
        cara = 'A_BASQUIN'
        call rcpare(nommat, pheno, cara, icodba)
        cara = 'A0'
        call rcpare(nommat, pheno, cara, icodhs)
        if (icodwo .eq. 0) then
            call fgdowh(nommat, ncyc, valmin, valmax, lke,&
                        zr(ivke), lhaigh, zr(ivcorr), vdommag)
        else if (icodba.eq.0) then
            call fgdoba(nommat, ncyc, valmin, valmax, lke,&
                        zr(ivke), lhaigh, zr(ivcorr), vdommag)
        else if (icodhs.eq.0) then
            call fgdohs(nommat, ncyc, valmin, valmax, lke,&
                        zr(ivke), lhaigh, zr(ivcorr), vdommag)
        endif
    else if (method.eq.'MANSON_COFFIN') then
        call fgdoma(nommat, ncyc, valmin, valmax, vdommag)
    else if (method.eq.'TAHERI_MANSON') then
        call fgtaep(nommat, nomfon, nomnap, ncyc, valmin,&
                    valmax, vdommag)
    else if (method.eq.'TAHERI_MIXTE') then
        call fgtaes(nommat, nomnap, ncyc, valmin, valmax,&
                    vdommag)
    else
        k16b = method(1:16)
        call utmess('F', 'PREPOST_4', sk=k16b)
    endif
!
    do 100 i = 1, ncyc
        dommag = dommag + vdommag(i)
100 end do
!
    AS_DEALLOCATE(vr=vdommag)
!    
    call jedetr('&&FGDOMG.HAIGC')
    call jedema()
end subroutine
