#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
import os
import multiprocessing

host_name = os.uname()[1] # Nome do PC
domain_name = 'barraco.lan' # Dominio
user_name = 'daniel' # Usuario
mem_bytes = int(os.sysconf('SC_PAGE_SIZE')*os.sysconf('SC_PHYS_PAGES')*1e-6)*0.95 # Quantidade de memoria RAM disponível.
threads=multiprocessing.cpu_count() # Numeros de nucleos de processamento da CPU

#ASTER_VERSION='12.6'
ASTER_VERSION='13.4'

ASTER_ROOT='/opt/aster-'+ASTER_VERSION
WORKING_DIR='/home/daniel/Downloads/study/'
ASTER_LIB_PATH=ASTER_ROOT+'/lib/python2.7/site-packages/'
JOBNAME='study'

ELEM_TYPE='COQUE_3D'
#ELEM_TYPE='DKTG'

solver='MULT_FRONT'
#solver='LDT'
#solver='MUMPS'
#solver='GCPC'
#solver='PETSC'

sys.path.append(ASTER_LIB_PATH) # Append the code_aster python library dir to system path.
sys.path.append(WORKING_DIR+"post")

raw_input("Construa a condição de contorno da malha cad.med")

def write_export(solver, condition):
    e = open(WORKING_DIR+JOBNAME+'.export','w')
    e.write('P actions make_etude\n')
    e.write('P nomjob '+JOBNAME+'\n') # Name of the job
    e.write('P consbtc oui\n') # to build (without soumetttre) the file btc. corefilesize
    e.write('P soumbtc oui\n')  # submission or not of the file .btc tpsjob maximum Time of the job
    e.write('P follow_output yes\n') # To ask (or not) the interactive follow-up of the execution.
    e.write('P tpsjob 35996400\n') # Time limit of the conclusion of the job in minutes
    e.write('P mem_aster 100\n') # Percentage of memjob alocate to study
    e.write('P memjob '+str(mem_bytes)+'\n') # Memory used in job in MB
    e.write('P memory_limit '+str(mem_bytes)+'\n') # Memory for Aster computation in MB
    e.write('P mode interactif\n')
    e.write('P ncpus '+str(threads)+'\n') # Number of process used by OpemMP
    e.write('P platform LINUX64\n') # Operational system of the host
    e.write('P proxy_dir /tmp\n') # Directory to store temporary files
    e.write('P rep_trav /tmp/'+JOBNAME+'\n') # Necessary to destroy working directory
    e.write('P version '+ASTER_VERSION+'\n') # Aster version used in study
    e.write('A args\n') 
    e.write('A memjeveux '+str(mem_bytes/8)+'\n') # Size of the memory taken by the execution (in MB). memjeveux = Total memory / 8
    e.write('A tpmax 35996400\n') # Limit of the time of the execution (in seconds)
    e.write('P time_limit 35996400\n') # time in seconds of subjected work
    e.write('P aster_root '+ASTER_ROOT+'\n') # Root directory of aster binary
    e.write('F mmed '+WORKING_DIR+JOBNAME+'.med  D 20\n') # MED file path and name
    e.write('F comm '+WORKING_DIR+JOBNAME+'.comm D  1\n') # COMM file path and name
    e.write('F mmed '+WORKING_DIR+JOBNAME+'.rmed R 80\n') # RMED file path and name
    e.write('F mess '+WORKING_DIR+JOBNAME+'.mess R  6\n') # MESS file path and name
    e.write('F resu '+WORKING_DIR+JOBNAME+'.resu R  8\n') # RESU file path and name
    if condition is "restart":
        e.write('R base '+WORKING_DIR+JOBNAME+'.base DC 0\n') # BASE file path and name
    e.write('R base '+WORKING_DIR+JOBNAME+'.base RC 0\n') # BASE file path and name
    
    if ( solver == 'MUMPS' or solver == 'PETSC' ):
      e.write('P profastk daniel@'+host_name+'.'+domain_name+':'+WORKING_DIR+JOBNAME+'.astk\n')
      e.write('P serveur '+host_name+'.'+domain_name+'\n')
      e.write('P username '+user_name+'\n')
      e.write('P protocol_exec asrun.plugins.server.SSHServer\n')
      e.write('P protocol_copyto asrun.plugins.server.SCPServer\n')
      e.write('P protocol_copyfrom asrun.plugins.server.SCPServer\n')
      e.write('P noeud '+host_name+'\n')
      e.write('P mclient '+host_name+'.'+domain_name+'\n')
      e.write('P uclient '+user_name+'\n')
      e.write('P lang en\n')
      e.write('P debug debug\n')
      e.write('P classe\n')
      e.write('P depart\n')
      e.write('P after_job\n')
      e.write('P distrib\n')
      e.write('P exectool\n')
      e.write('P multiple\n')
      e.write('P display Daniel-PC.barraco.lan:0\n')
      #e.write('P mpi_nbcpu '+str(threads)+'\n') # Total number of allocated MPI processes
      e.write('P mpi_nbcpu 1\n') # Total number of allocated MPI processes
      e.write('P mpi_nbnoeud 1\n') # Number of nodes used by MPI
      e.write('P nbmaxnook 5\n')
      e.write('P cpresok RESNOOK\n')
      e.write('P only_nook\n')
      e.write('P facmtps 1\n')
      e.write('P corefilesize unlimited\n')
    e.close()
def call_aster():
    if not os.path.exists(WORKING_DIR+JOBNAME+".base"):
        os.makedirs(WORKING_DIR+JOBNAME+".base")
    # Import the asrun class to execute the main class.
    import asrun
    from asrun.main import main,start
    del sys.argv[0]
    # Define the execution arguments
    sys.argv = [ASTER_ROOT+'/bin/as_run', '--vers='+ASTER_VERSION, WORKING_DIR+JOBNAME+'.export']
    # Call the main method to execute the study
    try:
        main()
    except:
        pass


write_export(solver,condition="restart") # Write the export file used by code_aster
call_aster() # Call the code_aster FEM solver.

