DEBUT(PAR_LOT='OUI', )

#-----------------------------------------------------------------------------#

mesh = LIRE_MAILLAGE(
    FORMAT='MED',
    INFO_MED=3,
    UNITE=20,
)

#-----------------------------------------------------------------------------#

model = AFFE_MODELE(
    AFFE=(
        _F(
            GROUP_MA='membrane',
            PHENOMENE='MECANIQUE',
            MODELISATION='MEMBRANE',
        ),
        _F(
            GROUP_MA='cables',
            PHENOMENE='MECANIQUE',
            MODELISATION='CABLE',
        ),
    ),
    MAILLAGE=mesh,
)

#-----------------------------------------------------------------------------#

materM = DEFI_MATERIAU(
    ELAS=_F(
        E=8e9,
        NU=0.4,
        RHO=1000,
        ALPHA=1.2E-5,
    ), )

materC = DEFI_MATERIAU(
    ELAS=_F(
        E=200e9,
        NU=0.3,
        RHO=7800,
        ALPHA=1.2E-5,
    ),
    CABLE=_F(EC_SUR_E=1.E-5),
)

#-----------------------------------------------------------------------------#

temp1 = CREA_CHAMP(
    TYPE_CHAM='NOEU_TEMP_R',
    MODELE=model,
    OPERATION='AFFE',
    AFFE=(_F(
        GROUP_MA='cables',
        NOM_CMP='TEMP',
        VALE=0.,
    ), ),
)

temp2 = CREA_CHAMP(
    MODELE=model,
    TYPE_CHAM='NOEU_TEMP_R',
    OPERATION='AFFE',
    AFFE=(_F(
        GROUP_MA='cables',
        NOM_CMP='TEMP',
        VALE=-12.04,
    ), ),
)

listemp = DEFI_LIST_REEL(VALE=(0.001, 1.0))

evtemp = CREA_RESU(
    TYPE_RESU='EVOL_VARC',
    NOM_CHAM='TEMP',
    OPERATION='AFFE',
    AFFE=(
        _F(
            CHAM_GD=temp1,
            INST=0.0,
        ),
        _F(
            CHAM_GD=temp2,
            LIST_INST=listemp,
        ),
    ),
)

#------------------------------------------------------------------------------#

fieldmat = AFFE_MATERIAU(
    AFFE=(
        _F(
            MATER=materM,
            GROUP_MA='membrane',
        ),
        _F(
            MATER=materC,
            GROUP_MA='cables',
        ),
    ),
    AFFE_VARC=_F(
        GROUP_MA='cables',
        NOM_VARC='TEMP',
        EVOL=evtemp,
        VALE_REF=0.0,
    ),
    MODELE=model,
)

#-----------------------------------------------------------------------------#

cara = AFFE_CARA_ELEM(
    MODELE=model,
    MEMBRANE=_F(
        GROUP_MA='membrane',
        EPAIS=2e-3,
        N_INIT=1.0,
    ),
    CABLE=_F(
        GROUP_MA='cables',
        SECTION=3.46E-4,
        N_INIT=1.0,
    ),
)

#-----------------------------------------------------------------------------#

pins = AFFE_CHAR_CINE(
    MECA_IMPO=_F(
        DX=0,
        DY=0,
        DZ=0,
        GROUP_MA='pins',
    ),
    MODELE=model,
)

#-----------------------------------------------------------------------------#

ramp = DEFI_FONCTION(
    NOM_PARA='INST',
    VALE=(0.0, 0.0, 1E-3, 1E-9, 1E-2, 1E-3, 0.1, 0.1, 1.0, 1.0),
)

Punif = AFFE_CHAR_MECA(
    PRES_REP=_F(
        GROUP_MA='membrane',
        PRES=1.0e3,
    ),
    MODELE=model,
)

#------------------------------------------------------------------------------#

lisnon = DEFI_LIST_REEL(VALE=(0.0, 1e-3, 1e-2, 0.1, 0.2, 0.3, 0.7, 1.0))

reslin = STAT_NON_LINE(
    TITRE='Analysis of a membrane',
    MODELE=model,
    CHAM_MATER=fieldmat,
    CARA_ELEM=cara,
    COMPORTEMENT=(
        _F(
            GROUP_MA='membrane',
            RELATION='ELAS_MEMBRANE_NH',
            DEFORMATION='GROT_GDEP',
        ),
        _F(
            GROUP_MA='cables',
            RELATION='CABLE',
            DEFORMATION='GROT_GDEP',
        ),
    ),
    EXCIT=(
        _F(CHARGE=pins, ),
        _F(CHARGE=Punif, FONC_MULT=ramp),
    ),
    INCREMENT=_F(LIST_INST=lisnon, ),
    CONVERGENCE=_F(
        ITER_GLOB_MAXI=1000,
        ITER_GLOB_ELAS=2500,
        RESI_GLOB_RELA=1.E-06,
        ARRET='OUI',
    ),
    NEWTON=_F(
        PREDICTION='TANGENTE',
        REAC_ITER=1,
        PAS_MINI_ELAS=1.E-03,
        MATRICE='TANGENTE',
        REAC_INCR=1,
    ),
    SOLVEUR=_F(
        STOP_SINGULIER='OUI',
        ELIM_LAGR='NON',
        NPREC=-1,
        METHODE='MUMPS',
    ),
)

#------------------------------------------------------------------------------#

reslin = CALC_CHAMP(
    RESULTAT=reslin,
    reuse=reslin,
    CONTRAINTE=('EFGE_ELNO'),
    FORCE=(
        'REAC_NODA',
        'FORC_NODA',
    ),
)

#------------------------------------------------------------------------------#

IMPR_RESU(
    FORMAT='RESULTAT',
    RESU=_F(
        FORMAT_R='1PE21.3',
        RESULTAT=reslin,
    ),
    UNITE=8,
)

IMPR_RESU(
    FORMAT='MED',
    RESU=_F(
        RESULTAT=reslin,
        IMPR_NOM_VARI='NON',
    ),
    UNITE=80,
)

#-----------------------------------------------------------------------------#

FIN()
